Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8194)

Unified Diff: chrome/browser/ui/zoom/chrome_zoom_level_prefs.h

Issue 393133002: Migrate HostZoomMap to live in StoragePartition. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments; patch for landing. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/zoom/chrome_zoom_level_prefs.h
diff --git a/chrome/browser/ui/zoom/chrome_zoom_level_prefs.h b/chrome/browser/ui/zoom/chrome_zoom_level_prefs.h
index ff0eb8499baaeb90bd8cd189d38478d9c7b880eb..e08aa6349fba90a3690574e28a9d0b524d1db9e3 100644
--- a/chrome/browser/ui/zoom/chrome_zoom_level_prefs.h
+++ b/chrome/browser/ui/zoom/chrome_zoom_level_prefs.h
@@ -15,6 +15,7 @@
#include "base/prefs/pref_service.h"
#include "base/prefs/pref_store.h"
#include "content/public/browser/host_zoom_map.h"
+#include "content/public/browser/zoom_level_delegate.h"
namespace base {
class DictionaryValue;
@@ -28,25 +29,22 @@ namespace chrome {
// to the per-partition default zoom levels from chrome/ flow through this
// class. Any changes to per-host levels are updated when HostZoomMap calls
// OnZoomLevelChanged.
-class ChromeZoomLevelPrefs {
+class ChromeZoomLevelPrefs : public content::ZoomLevelDelegate {
public:
typedef base::CallbackList<void(void)>::Subscription
DefaultZoomLevelSubscription;
- // Initialize the pref_service and the profile_path via the constructor,
+ // Initialize the pref_service and the partition_key via the constructor,
// as these concepts won't be available in the content base class
// (to be added later) which will define the InitPrefsAndCopyToHostZoomMap
// interface. |pref_service_| must outlive this class.
ChromeZoomLevelPrefs(PrefService* pref_service,
- const base::FilePath& profile_path);
+ const base::FilePath& profile_path,
+ const base::FilePath& partition_path);
virtual ~ChromeZoomLevelPrefs();
static std::string GetHashForTesting(const base::FilePath& relative_path);
- virtual void InitPrefsAndCopyToHostZoomMap(
- const base::FilePath& partition_path,
- content::HostZoomMap* host_zoom_map);
-
void SetDefaultZoomLevelPref(double level);
double GetDefaultZoomLevelPref() const;
scoped_ptr<DefaultZoomLevelSubscription> RegisterDefaultZoomLevelCallback(
@@ -56,6 +54,9 @@ class ChromeZoomLevelPrefs {
const base::DictionaryValue* host_zoom_dictionary,
bool sanitize_partition_host_zoom_levels);
+ // content::ZoomLevelDelegate
+ void InitHostZoomMap(content::HostZoomMap* host_zoom_map) override;
+
private:
// This is a callback function that receives notifications from HostZoomMap
// when per-host zoom levels change. It is used to update the per-host
@@ -63,7 +64,6 @@ class ChromeZoomLevelPrefs {
void OnZoomLevelChanged(const content::HostZoomMap::ZoomLevelChange& change);
PrefService* pref_service_;
- const base::FilePath profile_path_;
content::HostZoomMap* host_zoom_map_;
scoped_ptr<content::HostZoomMap::Subscription> zoom_subscription_;
std::string partition_key_;
@@ -28,25 +29,22 @@ namespace chrome {
// as these concepts won't be available in the content base class
- // (to be added later) which will define the InitPrefsAndCopyToHostZoomMap
- // interface. |pref_service_| must outlive this class.
+ // ZoomLevelDelegate, which will define the InitHostZoomMap interface.
+ // |pref_service_| must outlive this class.
ChromeZoomLevelPrefs(PrefService* pref_service,
« no previous file with comments | « chrome/browser/ui/webui/options/content_settings_handler.cc ('k') | chrome/browser/ui/zoom/chrome_zoom_level_prefs.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698